@@ -21,10 +21,6 @@ def simple_numpy_docstring(arg1, arg2="string"):
         Description of `arg1`
     arg2 : str
         Description of `arg2`
-    Returns
-    -------
-    str
-        Description of return value.
     """
     return int(arg1) * arg2
 
